@@ -1,10 +1,10 @@
 package Statistics::Sampler::Multinomial;
 
-use 5.010;
+use 5.014;
 use warnings;
 use strict;
 
-our $VERSION = '0.2';
+our $VERSION = '0.4';
 
 use Carp;
 use Ref::Util qw /is_arrayref/;
@@ -147,6 +147,7 @@ package Statistics::Sampler::Multinomial::DefaultPRNG {
     sub binomial {
         ...
     }
+    1;
 }
 
 
@@ -158,12 +159,6 @@ __END__
 Statistics::Sampler::Multinomial - Generate multinomial samples
 using the conditional binomial method.
 
-
-=head1 VERSION
-
-This document describes Statistics::Sampler::Multinomial version 0.1
-
-
 =head1 SYNOPSIS
 
     use Statistics::Sampler::Multinomial;
@@ -173,6 +168,7 @@ This document describes Statistics::Sampler::Multinomial version 0.1
     );
     $object->draw;
     #  returns a number between 0..3
+
     my $samples = $object->draw_n_samples(5)
     #  returns an array ref that might look something like
     #  [3,3,0,2,0]
@@ -203,9 +199,9 @@ see L<http://www.keithschwarz.com/darts-dice-coins>.
 
 =over 4
 
-=item my $object = Statistics::Sampler::Multinomial->new()
+=item my $object = Statistics::Sampler::Multinomial->new(data => [0.1, 0.4, 0.5], data_sum_to_one => 1)
 
-=item my $object = Statistics::Sampler::Multinomial->new (prng => $prng)
+=item my $object = Statistics::Sampler::Multinomial->new (data => [1,2,3,4,5,100], prng => $prng)
 
 Creates a new object, optionally passing a PRNG object to be used.
 
