@@ -1,10 +1,10 @@
 package Statistics::Sampler::Multinomial::AliasMethod;
 
-use 5.010;
+use 5.014;
 use warnings;
 use strict;
 
-our $VERSION = '0.02';
+our $VERSION = '0.4';
 
 use Carp;
 use Ref::Util qw /is_arrayref/;
@@ -155,6 +155,7 @@ package Statistics::Sampler::Multinomial::AliasMethod::DefaultPRNG {
     sub rand {
         rand();
     }
+    1;
 }
 
 1;
@@ -165,11 +166,6 @@ __END__
 Statistics::Sampler::Multinomial - Generate multinomial samples using Vose's alias method
 
 
-=head1 VERSION
-
-This document describes Statistics::Sampler::Multinomial version 0.01
-
-
 =head1 SYNOPSIS
 
     use Statistics::Sampler::Multinomial::AliasMethod;
@@ -179,6 +175,7 @@ This document describes Statistics::Sampler::Multinomial version 0.01
     );
     $object->draw;
     #  returns a number between 0..3
+    
     my $samples = $object->draw_n_samples(5)
     #  returns an array ref that might look something like
     #  [3,3,0,2,0]
@@ -258,6 +255,13 @@ or zero if initialise has not yet been run.
 
 =head1 BUGS AND LIMITATIONS
 
+Note that the results will differ between standard double
+and long double builds of Perl.
+
+L<Math::Random::MT::Auto> (a useful PRNG package) also gives different results
+between x32 and x64 architectures.  
+
+
 Please report any bugs or feature requests to
 L<https://github.com/shawnlaffan/perl-statistics-sampler-multinomial/issues>.
 
